% step_response_plot.m
% 18/11/2020
% Plot of the step response of the Qube angular velocity and voltage input

clear;
close all;
clc

load data_step_Qube
data0=data_step;

t=data0(1,:)';  % time-instant
y=data0(2,:)'; % angular velocity in rad/sec
u=data0(3,:)';  % motor input voltage in V
Ts=t(2)-t(1);   % Sampling period in sec

theta=cumsum(y)*Ts; % angular position estimate in rad

figure
subplot(3,1,1)
plot(t,theta,'r','linewidth',2)
legend('Angular position (rad)','location','northwest')
axis([0 t(end) 0 max(theta)+20])
set(gca,'FontSize',12,'FontName','helvetica');
grid
subplot(3,1,2)
plot(t,y,'r','linewidth',2)
legend('Angular velocity (rad/s)','location','northwest')
set(gca,'FontSize',12,'FontName','helvetica');
axis([0 t(end) 0 max(y)+10])
grid
subplot(3,1,3)
plot(t,u,'r','linewidth',2)
legend('Motor input voltage (V)','location','northwest')
xlabel('Time (seconds)')
axis([0 t(end) 0 2.5])
set(gca,'FontSize',12,'FontName','helvetica');
grid
